# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLFFT_METADATA = Metadata(
    id="31b0f974fa6340f6c9757e025d96c7c62a1daee6.boutiques",
    name="fslfft",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslfftOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslfft(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output volume result of the Fourier transform"""


def fslfft(
    input_volume: InputPathType,
    output_volume: InputPathType,
    inverse_flag: bool = False,
    runner: Runner | None = None,
) -> FslfftOutputs:
    """
    A tool to compute the Fourier transform of an input volume and save the result
    in an output volume.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FT
    
    Args:
        input_volume: Input volume file (e.g. invol.nii.gz).
        output_volume: Output volume file (e.g. outvol.nii.gz).
        inverse_flag: Flag to perform the inverse Fourier transform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslfftOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLFFT_METADATA)
    cargs = []
    cargs.append("fslfft")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(output_volume))
    if inverse_flag:
        cargs.append("-inv")
    ret = FslfftOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(output_volume).name + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLFFT_METADATA",
    "FslfftOutputs",
    "fslfft",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PTOZ_METADATA = Metadata(
    id="83cf3188521a93de48419a7ce77e274ee8127ed5.boutiques",
    name="ptoz",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PtozOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ptoz(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def ptoz(
    p_value: float,
    tail_flag: bool = False,
    grf_flag: float | None = None,
    runner: Runner | None = None,
) -> PtozOutputs:
    """
    Convert p-values to z-values.
    
    Author: Statistical Parametric Mapping (SPM)
    
    Args:
        p_value: p-value to convert.
        tail_flag: Use 2-tailed conversion.
        grf_flag: Use GRF maximum-height theory instead of Gaussian pdf.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PtozOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PTOZ_METADATA)
    cargs = []
    cargs.append("ptoz")
    cargs.append(str(p_value))
    if tail_flag:
        cargs.append("-2")
    if grf_flag is not None:
        cargs.extend([
            "-g",
            str(grf_flag)
        ])
    ret = PtozOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PTOZ_METADATA",
    "PtozOutputs",
    "ptoz",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLCOMPLEX_METADATA = Metadata(
    id="04bdecac3ae0becd85cc68c90704b37e0ef54666.boutiques",
    name="fslcomplex",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslcomplexOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslcomplex(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result_output_file: OutputPathType
    """The resulting output file from the specified operation."""


def fslcomplex(
    runner: Runner | None = None,
) -> FslcomplexOutputs:
    """
    Tool for manipulating complex-valued MR data.
    
    Author: FMRIB Analysis Group, Oxford University, UK
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslcomplexOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLCOMPLEX_METADATA)
    cargs = []
    cargs.append("fslcomplex")
    cargs.append("<outputtype>")
    cargs.append("<input>")
    cargs.append("<output>")
    cargs.append("[startvol")
    cargs.append("[endvol]]")
    ret = FslcomplexOutputs(
        root=execution.output_file("."),
        result_output_file=execution.output_file("[OUTPUT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLCOMPLEX_METADATA",
    "FslcomplexOutputs",
    "fslcomplex",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLASCII2IMG_METADATA = Metadata(
    id="05f4f1fe8989e2b97f3ccc41cb0004a9c7d240be.boutiques",
    name="fslascii2img",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Fslascii2imgOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslascii2img(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Converted NIfTI file from ASCII input"""


def fslascii2img(
    infile: InputPathType,
    xsize: int,
    ysize: int,
    zsize: int,
    tsize: int,
    xdim: float,
    ydim: float,
    zdim: float,
    tr: float,
    outfile: str = "output",
    runner: Runner | None = None,
) -> Fslascii2imgOutputs:
    """
    Convert data from ASCII format to NIfTI format.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        infile: Input ASCII file.
        xsize: Size in the x dimension (in voxels).
        ysize: Size in the y dimension (in voxels).
        zsize: Size in the z dimension (in voxels).
        tsize: Size in the t dimension (in voxels).
        xdim: Dimension size in the x dimension (in mm).
        ydim: Dimension size in the y dimension (in mm).
        zdim: Dimension size in the z dimension (in mm).
        tr: Repetition time (TR) in seconds.
        outfile: Output NIfTI file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fslascii2imgOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLASCII2IMG_METADATA)
    cargs = []
    cargs.append("fslascii2img")
    cargs.append(execution.input_file(infile))
    cargs.append(str(xsize))
    cargs.append(str(ysize))
    cargs.append(str(zsize))
    cargs.append(str(tsize))
    cargs.append(str(xdim))
    cargs.append(str(ydim))
    cargs.append(str(zdim))
    cargs.append(str(tr))
    cargs.append(outfile)
    ret = Fslascii2imgOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLASCII2IMG_METADATA",
    "Fslascii2imgOutputs",
    "fslascii2img",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_SURF2_VOL_METADATA = Metadata(
    id="a6bb6d317a47760e2a6d03dd8a906341403df071.boutiques",
    name="3dSurf2Vol",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dSurf2VolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_surf2_vol(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output dataset"""


def v_3d_surf2_vol(
    spec: InputPathType,
    surface_volume: InputPathType,
    surf_a: str,
    grid_parent: InputPathType,
    map_func: str,
    prefix: str,
    surf_b: str | None = None,
    surf_xyz_1d: InputPathType | None = None,
    sdata_1d: InputPathType | None = None,
    sdata: InputPathType | None = None,
    f_steps: float | None = None,
    f_index: str | None = None,
    f_p1_fr: float | None = None,
    f_pn_fr: float | None = None,
    f_p1_mm: float | None = None,
    f_pn_mm: float | None = None,
    stop_gap: bool = False,
    cmask: str | None = None,
    data_expr: str | None = None,
    datum: str | None = None,
    debug: int | None = None,
    dnode: int | None = None,
    dvoxel: int | None = None,
    noscale: bool = False,
    sxyz_orient_as_gpar: bool = False,
    runner: Runner | None = None,
) -> V3dSurf2VolOutputs:
    """
    Map data from a surface domain to an AFNI volume domain.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dSurf2Vol.html
    
    Args:
        spec: SUMA spec file.
        surface_volume: AFNI surface volume dataset.
        surf_a: Specify surface A from spec file.
        grid_parent: AFNI grid parent dataset.
        map_func: Surface to dataset function.
        prefix: Prefix for the output dataset.
        surf_b: Specify surface B from spec file.
        surf_xyz_1d: 1D coordinate file.
        sdata_1d: 1D sub-surface data file.
        sdata: NIML or GIFTI formatted dataset.
        f_steps: Partition segments into this many steps.
        f_index: Index by points or voxels.
        f_p1_fr: Offset p1 by a fraction of the length.
        f_pn_fr: Offset pn by a fraction of the length.
        f_p1_mm: Offset p1 by a distance in mm.
        f_pn_mm: Offset pn by a distance in mm.
        stop_gap: Stop when a zero gap has been hit.
        cmask: Command for dataset mask.
        data_expr: Apply expression to surface input.
        datum: Set data type in output dataset.
        debug: Verbose output level.
        dnode: Extra output for specified node.
        dvoxel: Extra output for specified voxel.
        noscale: No scale factor in output dataset.
        sxyz_orient_as_gpar: Assume grid parent orientation for surface xyz.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dSurf2VolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_SURF2_VOL_METADATA)
    cargs = []
    cargs.append("3dSurf2Vol")
    cargs.extend([
        "-spec",
        execution.input_file(spec)
    ])
    cargs.extend([
        "-sv",
        execution.input_file(surface_volume)
    ])
    cargs.extend([
        "-surf_A",
        surf_a
    ])
    if surf_b is not None:
        cargs.extend([
            "-surf_B",
            surf_b
        ])
    cargs.extend([
        "-grid_parent",
        execution.input_file(grid_parent)
    ])
    cargs.extend([
        "-map_func",
        map_func
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if surf_xyz_1d is not None:
        cargs.extend([
            "-surf_xyz_1D",
            execution.input_file(surf_xyz_1d)
        ])
    if sdata_1d is not None:
        cargs.extend([
            "-sdata_1D",
            execution.input_file(sdata_1d)
        ])
    if sdata is not None:
        cargs.extend([
            "-sdata",
            execution.input_file(sdata)
        ])
    if f_steps is not None:
        cargs.extend([
            "-f_steps",
            str(f_steps)
        ])
    if f_index is not None:
        cargs.extend([
            "-f_index",
            f_index
        ])
    if f_p1_fr is not None:
        cargs.extend([
            "-f_p1_fr",
            str(f_p1_fr)
        ])
    if f_pn_fr is not None:
        cargs.extend([
            "-f_pn_fr",
            str(f_pn_fr)
        ])
    if f_p1_mm is not None:
        cargs.extend([
            "-f_p1_mm",
            str(f_p1_mm)
        ])
    if f_pn_mm is not None:
        cargs.extend([
            "-f_pn_mm",
            str(f_pn_mm)
        ])
    if stop_gap:
        cargs.append("-stop_gap")
    if cmask is not None:
        cargs.extend([
            "-cmask",
            cmask
        ])
    if data_expr is not None:
        cargs.extend([
            "-data_expr",
            data_expr
        ])
    if datum is not None:
        cargs.extend([
            "-datum",
            datum
        ])
    if debug is not None:
        cargs.extend([
            "-debug",
            str(debug)
        ])
    if dnode is not None:
        cargs.extend([
            "-dnode",
            str(dnode)
        ])
    if dvoxel is not None:
        cargs.extend([
            "-dvoxel",
            str(dvoxel)
        ])
    if noscale:
        cargs.append("-noscale")
    if sxyz_orient_as_gpar:
        cargs.append("-sxyz_orient_as_gpar")
    ret = V3dSurf2VolOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + "+*[gz]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dSurf2VolOutputs",
    "V_3D_SURF2_VOL_METADATA",
    "v_3d_surf2_vol",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__CHAUFFEUR_AFNI_METADATA = Metadata(
    id="156b32bc2ae285398a04b90d562966dd0cfac2d3.boutiques",
    name="@chauffeur_afni",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VChauffeurAfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__chauffeur_afni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """Generated montage image"""
    cluster_report: OutputPathType
    """Clusterization report"""
    whereami_report: OutputPathType
    """Whereami report for clusterized data"""


def v__chauffeur_afni(
    ulay: InputPathType,
    prefix: str,
    olay: InputPathType | None = None,
    runner: Runner | None = None,
) -> VChauffeurAfniOutputs:
    """
    Automated QC snapshots generator in AFNI.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@chauffeur_afni.html
    
    Args:
        ulay: Name of underlay dataset (required); can be 3D or 4D set.
        prefix: Prefix for output files (required).
        olay: Name of overlay dataset (optional).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VChauffeurAfniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__CHAUFFEUR_AFNI_METADATA)
    cargs = []
    cargs.append("@chauffeur_afni")
    cargs.append(execution.input_file(ulay))
    if olay is not None:
        cargs.append(execution.input_file(olay))
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.append("[options]")
    ret = VChauffeurAfniOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(prefix + ".png"),
        cluster_report=execution.output_file(prefix + "_clust_rep.txt"),
        whereami_report=execution.output_file(prefix + "_clust_whereami.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VChauffeurAfniOutputs",
    "V__CHAUFFEUR_AFNI_METADATA",
    "v__chauffeur_afni",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_MBM_MARMOSET_METADATA = Metadata(
    id="f5f69f845ca75bf6764009410dc0384dc0ba5615.boutiques",
    name="@Install_MBM_Marmoset",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallMbmMarmosetOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_mbm_marmoset(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__install_mbm_marmoset(
    wget: bool = False,
    curl: bool = False,
    runner: Runner | None = None,
) -> VInstallMbmMarmosetOutputs:
    """
    Installs the NIH marmoset template and atlases.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_MBM_Marmoset.html
    
    Args:
        wget: Use wget to download archive. Script chooses by default with\
            preference for curl.
        curl: Use curl to download archive. Script chooses by default with\
            preference for curl.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallMbmMarmosetOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_MBM_MARMOSET_METADATA)
    cargs = []
    cargs.append("@Install_MBM_Marmoset")
    if wget:
        cargs.append("-wget")
    if curl:
        cargs.append("-curl")
    ret = VInstallMbmMarmosetOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallMbmMarmosetOutputs",
    "V__INSTALL_MBM_MARMOSET_METADATA",
    "v__install_mbm_marmoset",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SLICES_METADATA = Metadata(
    id="d7686727236e96e34bd6ab2accde7439c67d1b81.boutiques",
    name="slices",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SlicesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `slices(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def slices(
    primary_input: InputPathType,
    secondary_input: InputPathType | None = None,
    scale_factor: float | None = None,
    output_gif: str | None = None,
    runner: Runner | None = None,
) -> SlicesOutputs:
    """
    Generate a set of slices from an image, possibly with some scaling and intensity
    range options, and save as a GIF.
    
    Author: Unknown
    
    Args:
        primary_input: Primary input image file (e.g. img1.nii.gz).
        secondary_input: Secondary input image file (e.g. img2.nii.gz).
        scale_factor: Scale factor to apply to images.
        output_gif: Output GIF file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SlicesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SLICES_METADATA)
    cargs = []
    cargs.append("slices")
    cargs.append(execution.input_file(primary_input))
    if secondary_input is not None:
        cargs.append(execution.input_file(secondary_input))
    cargs.append("-s")
    if scale_factor is not None:
        cargs.extend([
            "-s",
            str(scale_factor)
        ])
    cargs.append("-i")
    cargs.append("[INTMIN]")
    cargs.append("[INTMAX]")
    cargs.append("-o")
    if output_gif is not None:
        cargs.extend([
            "-o",
            output_gif
        ])
    ret = SlicesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SLICES_METADATA",
    "SlicesOutputs",
    "slices",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_REMOVE_ISLANDS_METADATA = Metadata(
    id="ccfb20f350c974adee896baa3f5aa1a71a238a25.boutiques",
    name="metric-remove-islands",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class MetricRemoveIslandsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_remove_islands(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output ROI metric"""


def metric_remove_islands(
    surface: InputPathType,
    metric_in: InputPathType,
    metric_out: str,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> MetricRemoveIslandsOutputs:
    """
    Remove islands from an roi metric.
    
    Finds all connected areas in the ROI, and zeros out all but the largest one,
    in terms of surface area.
    
    Author: Washington University School of Medicin
    
    Args:
        surface: the surface to use for neighbor information.
        metric_in: the input ROI metric.
        metric_out: the output ROI metric.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricRemoveIslandsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_REMOVE_ISLANDS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-remove-islands")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(metric_in))
    cargs.append(metric_out)
    if opt_corrected_areas_area_metric is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(opt_corrected_areas_area_metric)
        ])
    ret = MetricRemoveIslandsOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_REMOVE_ISLANDS_METADATA",
    "MetricRemoveIslandsOutputs",
    "metric_remove_islands",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FILMBABE_METADATA = Metadata(
    id="5aeaa63a2b4af0df1c495362f58a31832031b867.boutiques",
    name="filmbabe",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FilmbabeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `filmbabe(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dir: OutputPathType
    """Output directory"""


def filmbabe(
    datafile_alias: InputPathType,
    mask_alias: InputPathType,
    designfile_alias_2: InputPathType,
    frf: InputPathType,
    verbose_flag_alias: bool = False,
    debug_level_alias_2: str | None = None,
    timing_on_flag: bool = False,
    help_flag_alias: bool = False,
    flobs_prior_off_alias: bool = False,
    flobs_dir: str | None = None,
    prior_covar_file_alias: InputPathType | None = None,
    prior_mean_file_alias: InputPathType | None = None,
    log_dir_alias_2: str | None = None,
    num_iterations: int | None = 5,
    temporal_ar_mrf_prec_alias: float | None = -1,
    temporal_ar_flag: bool = False,
    num_trace_samples_alias: int | None = 0,
    temporal_ar_order: int | None = 3,
    runner: Runner | None = None,
) -> FilmbabeOutputs:
    """
    FILM with MCMC-based Bayesian Analysis for fMRI.
    
    Author: FMRIB Analysis Group, Oxford University, UK
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
    
    Args:
        datafile_alias: Data file.
        mask_alias: Mask file.
        designfile_alias_2: Design matrix file.
        frf: File indicating which regressors belong to which original EV\
            design matrix file (a -1 label indicates a non-flobs regressor).
        verbose_flag_alias: Switch on diagnostic messages.
        debug_level_alias_2: Set debug level.
        timing_on_flag: Turn timing on.
        help_flag_alias: Display help message.
        flobs_prior_off_alias: Turn FLOBS prior off.
        flobs_dir: FLOBS directory; required when using FLOBS constraints.
        prior_covar_file_alias: Prior covariance matrix file.
        prior_mean_file_alias: Prior mean matrix file.
        log_dir_alias_2: Log directory.
        num_iterations: Number of VB iterations; default is 5.
        temporal_ar_mrf_prec_alias: MRF precision to impose on temporal AR\
            maps, default is -1 for a proper full Bayes approach.
        temporal_ar_flag: Impose ARD/MRF on temporal AR.
        num_trace_samples_alias: Number of samples to take to estimate trace;\
            default is 0 (uses only diagonal elements of precision matrix to\
            estimate trace).
        temporal_ar_order: Order of temporal AR; default is 3.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FilmbabeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FILMBABE_METADATA)
    cargs = []
    cargs.append("filmbabe")
    cargs.extend([
        "--datafile",
        execution.input_file(datafile_alias)
    ])
    cargs.extend([
        "--mask",
        execution.input_file(mask_alias)
    ])
    cargs.extend([
        "--designfile",
        execution.input_file(designfile_alias_2)
    ])
    cargs.extend([
        "--frf",
        execution.input_file(frf)
    ])
    if verbose_flag_alias:
        cargs.append("--verbose")
    if debug_level_alias_2 is not None:
        cargs.extend([
            "--debuglevel",
            debug_level_alias_2
        ])
    if timing_on_flag:
        cargs.append("--to")
    if help_flag_alias:
        cargs.append("--help")
    if flobs_prior_off_alias:
        cargs.append("--flobsprioroff")
    if flobs_dir is not None:
        cargs.extend([
            "--fd",
            flobs_dir
        ])
    if prior_covar_file_alias is not None:
        cargs.extend([
            "--priorcovarfile",
            execution.input_file(prior_covar_file_alias)
        ])
    if prior_mean_file_alias is not None:
        cargs.extend([
            "--priormeanfile",
            execution.input_file(prior_mean_file_alias)
        ])
    if log_dir_alias_2 is not None:
        cargs.extend([
            "--logdir",
            log_dir_alias_2
        ])
    if num_iterations is not None:
        cargs.extend([
            "--ni",
            str(num_iterations)
        ])
    if temporal_ar_mrf_prec_alias is not None:
        cargs.extend([
            "--tarmrfprec",
            str(temporal_ar_mrf_prec_alias)
        ])
    if temporal_ar_flag:
        cargs.append("--tarard")
    if num_trace_samples_alias is not None:
        cargs.extend([
            "--ntracesamps",
            str(num_trace_samples_alias)
        ])
    if temporal_ar_order is not None:
        cargs.extend([
            "--ntar",
            str(temporal_ar_order)
        ])
    ret = FilmbabeOutputs(
        root=execution.output_file("."),
        output_dir=execution.output_file("output"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FILMBABE_METADATA",
    "FilmbabeOutputs",
    "filmbabe",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_METRICS_METADATA = Metadata(
    id="f8b017306eb69e262fc909f3128e1463d124c4e8.boutiques",
    name="SurfaceMetrics",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfaceMetricsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_metrics(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surface_metrics(
    runner: Runner | None = None,
) -> SurfaceMetricsOutputs:
    """
    Outputs information about a surface's mesh.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfaceMetrics.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceMetricsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_METRICS_METADATA)
    cargs = []
    cargs.append("SurfaceMetrics")
    cargs.append("<METRIC>")
    cargs.append("-SURF_1")
    cargs.append("[-tlrc]")
    cargs.append("[-prefix")
    cargs.append("PREFIX]")
    ret = SurfaceMetricsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_METRICS_METADATA",
    "SurfaceMetricsOutputs",
    "surface_metrics",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ROISTATS_METADATA = Metadata(
    id="837cb344ffaa7fe7aa684a462d2ab5e156a15242.boutiques",
    name="3dROIstats",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dRoistatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_roistats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output file."""
    out_file_: OutputPathType
    """Output tab-separated values file."""


def v_3d_roistats(
    in_file: InputPathType,
    mask: InputPathType | None = None,
    debug: bool = False,
    format1_d: bool = False,
    format1_dr: bool = False,
    mask_f2short: bool = False,
    mask_file: InputPathType | None = None,
    nobriklab: bool = False,
    nomeanout: bool = False,
    num_roi: int | None = None,
    quiet: bool = False,
    roisel: InputPathType | None = None,
    stat_: list[InputPathType] | None = None,
    zerofill: str | None = None,
    runner: Runner | None = None,
) -> V3dRoistatsOutputs:
    """
    Display statistics over masked regions.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dROIstats.html
    
    Args:
        in_file: Input dataset.
        mask: Input mask.
        debug: Print debug information.
        format1_d: Output results in a 1d format that includes commented\
            labels.
        format1_dr: Output results in a 1d format that includes uncommented\
            labels. may not work optimally with typical 1d functions, but is useful\
            for r functions.
        mask_f2short: Tells the program to convert a float mask to short\
            integers, by simple rounding.
        mask_file: Input mask.
        nobriklab: Do not print the sub-brick label next to its index.
        nomeanout: Do not include the (zero-inclusive) mean among computed\
            stats.
        num_roi: Forces the assumption that the mask dataset's rois are denoted\
            by 1 to n inclusive. normally, the program figures out the rois on its\
            own. this option is useful if a) you are certain that the mask dataset\
            has no values outside the range [0 n], b) there may be some rois\
            missing between [1 n] in the mask data-set and c) you want those\
            columns in the output any-way so the output lines up with the output\
            from other invocations of 3droistats.
        quiet: Execute quietly.
        roisel: Only considers rois denoted by values found in the specified\
            file. note that the order of the rois as specified in the file is not\
            preserved. so an sel.1d of '2 8 20' produces the same output as '8 20\
            2'.
        stat_: A list of items which are 'mean' or 'sum' or 'voxels' or\
            'minmax' or 'sigma' or 'median' or 'mode' or 'summary' or 'zerominmax'\
            or 'zerosigma' or 'zeromedian' or 'zeromode'. Statistics to compute.\
            options include: * mean = compute the mean using only non_zero voxels.\
            implies the opposite for the mean computed by default. * median =\
            compute the median of nonzero voxels * mode = compute the mode of\
            nonzero voxels. (integral valued sets only) * minmax = compute the\
            min/max of nonzero voxels * sum = compute the sum using only nonzero\
            voxels. * voxels = compute the number of nonzero voxels * sigma =\
            compute the standard deviation of nonzero voxelsstatistics that include\
            zero-valued voxels: * zerominmax = compute the min/max of all voxels. *\
            zerosigma = compute the standard deviation of all voxels. * zeromedian\
            = compute the median of all voxels. * zeromode = compute the mode of\
            all voxels. * summary = only output a summary line with the grand mean\
            across all briks in the input dataset. this option cannot be used with\
            nomeanout.more that one option can be specified.
        zerofill: For roi labels not found, use the provided string instead of\
            a '0' in the output file. only active if `num_roi` is enabled.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dRoistatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ROISTATS_METADATA)
    cargs = []
    cargs.append("3dROIstats")
    cargs.append(execution.input_file(in_file))
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    cargs.append("[OUT_FILE]")
    if debug:
        cargs.append("-debug")
    if format1_d:
        cargs.append("-1Dformat")
    if format1_dr:
        cargs.append("-1DRformat")
    if mask_f2short:
        cargs.append("-mask_f2short")
    if mask_file is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_file)
        ])
    if nobriklab:
        cargs.append("-nobriklab")
    if nomeanout:
        cargs.append("-nomeanout")
    if num_roi is not None:
        cargs.extend([
            "-numroi",
            str(num_roi)
        ])
    if quiet:
        cargs.append("-quiet")
    if roisel is not None:
        cargs.extend([
            "-roisel",
            execution.input_file(roisel)
        ])
    if stat_ is not None:
        cargs.extend([execution.input_file(f) for f in stat_])
    if zerofill is not None:
        cargs.extend([
            "-zerofill",
            zerofill
        ])
    ret = V3dRoistatsOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_file).name + "_roistat.1D"),
        out_file_=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dRoistatsOutputs",
    "V_3D_ROISTATS_METADATA",
    "v_3d_roistats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MCFLIRT_METADATA = Metadata(
    id="b4197d99afbb918d62f2efb020e00449c785918e.boutiques",
    name="mcflirt",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class McflirtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mcflirt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    mat_file: OutputPathType
    """A list of items which are an existing file name. Transformation
    matrices."""
    mean_img: OutputPathType | None
    """Mean timeseries image (if mean_vol=true)."""
    out_file_outfile: OutputPathType | None
    """Motion-corrected timeseries."""
    par_file: OutputPathType | None
    """Text-file with motion parameters."""
    rms_files: OutputPathType | None
    """A list of items which are an existing file name. Absolute and relative
    displacement parameters."""
    std_img: OutputPathType | None
    """Standard deviation image."""
    variance_img: OutputPathType | None
    """Variance image."""


def mcflirt(
    in_file: InputPathType,
    bins: int | None = None,
    cost: typing.Literal["mutualinfo", "woods", "corratio", "normcorr", "normmi", "leastsquares"] | None = None,
    dof: int | None = None,
    init: InputPathType | None = None,
    interpolation: typing.Literal["spline_final", "nn_final", "sinc_final"] | None = None,
    mean_vol: bool = False,
    out_file: InputPathType | None = None,
    ref_file: InputPathType | None = None,
    ref_vol: int | None = None,
    rotation: int | None = None,
    save_mats: bool = False,
    save_plots: bool = False,
    save_rms: bool = False,
    scaling: float | None = None,
    smooth: float | None = None,
    stages: int | None = None,
    stats_imgs: bool = False,
    use_contour: bool = False,
    use_gradient: bool = False,
    runner: Runner | None = None,
) -> McflirtOutputs:
    """
    MCFLIRT is an intra-modal motion correction tool designed for use on fMRI time
    series and based on optimization and registration techniques used in FLIRT, a
    fully automated robust and accurate tool for linear (affine) inter- and
    inter-modal brain image registration.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/MCFLIRT
    
    Args:
        in_file: Timeseries to motion-correct.
        bins: Number of histogram bins.
        cost: 'mutualinfo' or 'woods' or 'corratio' or 'normcorr' or 'normmi'\
            or 'leastsquares'. Cost function to optimize.
        dof: Degrees of freedom for the transformation.
        init: Initial transformation matrix.
        interpolation: 'spline' or 'nn' or 'sinc'. Interpolation method for\
            transformation.
        mean_vol: Register to mean volume.
        out_file: File to write.
        ref_file: Target image for motion correction.
        ref_vol: Volume to align frames to.
        rotation: Scaling factor for rotation tolerances.
        save_mats: Save transformation matrices.
        save_plots: Save transformation parameters.
        save_rms: Save rms displacement parameters.
        scaling: Scaling factor to use.
        smooth: Smoothing factor for the cost function.
        stages: Stages (if 4, perform final search with sinc interpolation.
        stats_imgs: Produce variance and std. dev. images.
        use_contour: Run search on contour images.
        use_gradient: Run search on gradient images.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `McflirtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MCFLIRT_METADATA)
    cargs = []
    cargs.append("mcflirt")
    cargs.extend([
        "-in",
        execution.input_file(in_file)
    ])
    if bins is not None:
        cargs.extend([
            "-bins",
            str(bins)
        ])
    if cost is not None:
        cargs.extend([
            "-cost",
            cost
        ])
    if dof is not None:
        cargs.extend([
            "-dof",
            str(dof)
        ])
    if init is not None:
        cargs.extend([
            "-init",
            execution.input_file(init)
        ])
    if interpolation is not None:
        cargs.append("-" + interpolation)
    if mean_vol:
        cargs.append("-meanvol")
    if out_file is not None:
        cargs.extend([
            "-out",
            execution.input_file(out_file)
        ])
    if ref_file is not None:
        cargs.extend([
            "-reffile",
            execution.input_file(ref_file)
        ])
    if ref_vol is not None:
        cargs.extend([
            "-refvol",
            str(ref_vol)
        ])
    if rotation is not None:
        cargs.extend([
            "-rotation",
            str(rotation)
        ])
    if save_mats:
        cargs.append("-mats")
    if save_plots:
        cargs.append("-plots")
    if save_rms:
        cargs.append("-rmsabs -rmsrel")
    if scaling is not None:
        cargs.extend([
            "-scaling",
            str(scaling)
        ])
    if smooth is not None:
        cargs.extend([
            "-smooth",
            str(smooth)
        ])
    if stages is not None:
        cargs.extend([
            "-stages",
            str(stages)
        ])
    if stats_imgs:
        cargs.append("-stats")
    if use_contour:
        cargs.append("-edge")
    if use_gradient:
        cargs.append("-gdt")
    ret = McflirtOutputs(
        root=execution.output_file("."),
        mat_file=execution.output_file("MAT_*"),
        mean_img=execution.output_file(pathlib.Path(out_file).name + "_mean_reg.ext") if (out_file is not None) else None,
        out_file_outfile=execution.output_file(pathlib.Path(out_file).name) if (out_file is not None) else None,
        par_file=execution.output_file(pathlib.Path(out_file).name + ".par") if (out_file is not None) else None,
        rms_files=execution.output_file(pathlib.Path(out_file).name + "_*.rms") if (out_file is not None) else None,
        std_img=execution.output_file(pathlib.Path(out_file).name + "_sigma.ext") if (out_file is not None) else None,
        variance_img=execution.output_file(pathlib.Path(out_file).name + "_variance.ext") if (out_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MCFLIRT_METADATA",
    "McflirtOutputs",
    "mcflirt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_CURVATURE_METADATA = Metadata(
    id="2504b15bc1ec1bebe9f157d99ecaf66b1f5987f8.boutiques",
    name="surface-curvature",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceCurvatureOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_curvature(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    mean_out: OutputPathType
    """mean curvature metric"""
    gauss_out: OutputPathType
    """gaussian curvature metric"""


def surface_curvature(
    surface: InputPathType,
    mean_out: str,
    gauss_out: str,
    opt_mean: bool = False,
    opt_gauss: bool = False,
    runner: Runner | None = None,
) -> SurfaceCurvatureOutputs:
    """
    Calculate curvature of surface.
    
    Compute the curvature of the surface, using the method from:
    Interactive Texture Mapping by J. Maillot, Yahia, and Verroust, 1993.
    ACM-0-98791-601-8/93/008.
    
    Author: Washington University School of Medicin
    
    Args:
        surface: the surface to compute the curvature of.
        mean_out: mean curvature metric.
        gauss_out: gaussian curvature metric.
        opt_mean: output mean curvature.
        opt_gauss: output gaussian curvature.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCurvatureOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_CURVATURE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-curvature")
    cargs.append(execution.input_file(surface))
    if opt_mean:
        cargs.append("-mean")
    cargs.append(mean_out)
    if opt_gauss:
        cargs.append("-gauss")
    cargs.append(gauss_out)
    ret = SurfaceCurvatureOutputs(
        root=execution.output_file("."),
        mean_out=execution.output_file(mean_out),
        gauss_out=execution.output_file(gauss_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_CURVATURE_METADATA",
    "SurfaceCurvatureOutputs",
    "surface_curvature",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIXELCONNECTIVITY_METADATA = Metadata(
    id="9c0aa46c302eaa38e8041b448650732830a3d850.boutiques",
    name="fixelconnectivity",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class FixelconnectivityConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class FixelconnectivityOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fixelconnectivity(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    matrix: OutputPathType
    """the output fixel-fixel connectivity matrix directory path"""


def fixelconnectivity(
    fixel_directory: InputPathType,
    tracks: InputPathType,
    matrix: str,
    threshold: float | None = None,
    angle: float | None = None,
    mask: InputPathType | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[FixelconnectivityConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> FixelconnectivityOutputs:
    """
    Generate a fixel-fixel connectivity matrix.
    
    This command will generate a directory containing three images, which
    encodes the fixel-fixel connectivity matrix. Documentation regarding this
    format and how to use it will come in the future.
    
    References:
    
    .
    
    Author: Robert E. Smith (robert.smith@florey.edu.au)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/fixelconnectivity.html
    
    Args:
        fixel_directory: the directory containing the fixels between which\
            connectivity will be quantified.
        tracks: the tracks used to determine fixel-fixel connectivity.
        matrix: the output fixel-fixel connectivity matrix directory path.
        threshold: a threshold to define the required fraction of shared\
            connections to be included in the neighbourhood (default: 0.01).
        angle: the max angle threshold for assigning streamline tangents to\
            fixels (Default: 45 degrees).
        mask: provide a fixel data file containing a mask of those fixels to be\
            computed; fixels outside the mask will be empty in the output matrix.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FixelconnectivityOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIXELCONNECTIVITY_METADATA)
    cargs = []
    cargs.append("fixelconnectivity")
    if threshold is not None:
        cargs.extend([
            "-threshold",
            str(threshold)
        ])
    if angle is not None:
        cargs.extend([
            "-angle",
            str(angle)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(fixel_directory))
    cargs.append(execution.input_file(tracks))
    cargs.append(matrix)
    ret = FixelconnectivityOutputs(
        root=execution.output_file("."),
        matrix=execution.output_file(matrix),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIXELCONNECTIVITY_METADATA",
    "FixelconnectivityConfig",
    "FixelconnectivityOutputs",
    "fixelconnectivity",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_FLIP_LR_METADATA = Metadata(
    id="be7ac8c956bb50120ee359df4df51ce488e5b406.boutiques",
    name="surface-flip-lr",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceFlipLrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_flip_lr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """the output flipped surface"""


def surface_flip_lr(
    surface: InputPathType,
    surface_out: str,
    runner: Runner | None = None,
) -> SurfaceFlipLrOutputs:
    """
    Mirror a surface through the yz plane.
    
    This command negates the x coordinate of each vertex, and flips the surface
    normals, so that you have a surface of opposite handedness with the same
    features and vertex correspondence, with normals consistent with the
    original surface. That is, if the input surface has normals facing outward,
    the output surface will also have normals facing outward.
    
    Author: Washington University School of Medicin
    
    Args:
        surface: the surface to flip.
        surface_out: the output flipped surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceFlipLrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_FLIP_LR_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-flip-lr")
    cargs.append(execution.input_file(surface))
    cargs.append(surface_out)
    ret = SurfaceFlipLrOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(surface_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_FLIP_LR_METADATA",
    "SurfaceFlipLrOutputs",
    "surface_flip_lr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UBER_SKEL_PY_METADATA = Metadata(
    id="072808117e1f9ebcb9f514ee1fafce9b67b7215b.boutiques",
    name="uber_skel.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class UberSkelPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `uber_skel_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def uber_skel_py(
    runner: Runner | None = None,
) -> UberSkelPyOutputs:
    """
    Sample uber processing program for initializing user and control variables, with
    options for both GUI and non-GUI modes.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/uber_skel.py.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UberSkelPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UBER_SKEL_PY_METADATA)
    cargs = []
    cargs.append("uber_skel.py")
    cargs.append("[OPTIONS]")
    ret = UberSkelPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UBER_SKEL_PY_METADATA",
    "UberSkelPyOutputs",
    "uber_skel_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__COMPUTE_OC_WEIGHTS_METADATA = Metadata(
    id="5e3f682a30f5996c6391430edd011c5417a938ae.boutiques",
    name="@compute_OC_weights",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VComputeOcWeightsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__compute_oc_weights(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_oc_weights: OutputPathType | None
    """Resulting OC weights dataset"""


def v__compute_oc_weights(
    echo_dsets: list[str],
    echo_times: str | None = None,
    prefix: str | None = None,
    def_to_equal: str | None = None,
    oc_method: str | None = None,
    sum_weight_tolerance: float | None = None,
    t2_star_limit: float | None = None,
    work_dir: str | None = None,
    verbosity: bool = False,
    runner: Runner | None = None,
) -> VComputeOcWeightsOutputs:
    """
    Compute optimal combined weights dataset for multi-echo EPI data.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@compute_OC_weights.html
    
    Args:
        echo_dsets: Specify one run of multi-echo EPI data.
        echo_times: Specify echo times as list (e.g., "15 30.5 41"). Use either\
            -echo_times or -echo_times_files.
        prefix: Specify prefix of resulting OC weights dataset (e.g.,\
            OC.weights.SUBJ).
        def_to_equal: Specify whether to default to equal weights (default =\
            no).
        oc_method: Specify which OC method to employ (default = OC_A).
        sum_weight_tolerance: Tolerance for summed weight difference from 1.0\
            (default = 0.001).
        t2_star_limit: Specify limit for T2* values (default = 300).
        work_dir: Specify directory to compute results in.
        verbosity: Increase verbosity of output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VComputeOcWeightsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__COMPUTE_OC_WEIGHTS_METADATA)
    cargs = []
    cargs.append("@compute_OC_weights")
    if echo_times is not None:
        cargs.extend([
            "-echo_times",
            echo_times
        ])
    cargs.extend([
        "-echo_dsets",
        *echo_dsets
    ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if def_to_equal is not None:
        cargs.extend([
            "-def_to_equal",
            def_to_equal
        ])
    if oc_method is not None:
        cargs.extend([
            "-oc_method",
            oc_method
        ])
    if sum_weight_tolerance is not None:
        cargs.extend([
            "-sum_weight_tolerance",
            str(sum_weight_tolerance)
        ])
    if t2_star_limit is not None:
        cargs.extend([
            "-t2_star_limit",
            str(t2_star_limit)
        ])
    if work_dir is not None:
        cargs.extend([
            "-work_dir",
            work_dir
        ])
    if verbosity:
        cargs.append("-verb")
    ret = VComputeOcWeightsOutputs(
        root=execution.output_file("."),
        output_oc_weights=execution.output_file(prefix + "+tlrc.HEAD") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VComputeOcWeightsOutputs",
    "V__COMPUTE_OC_WEIGHTS_METADATA",
    "v__compute_oc_weights",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AMP2RESPONSE_METADATA = Metadata(
    id="333417acbc4400d2f027a5765d8cc04968437cab.boutiques",
    name="amp2response",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Amp2responseConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Amp2responseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `amp2response(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    response: OutputPathType
    """the output zonal spherical harmonic coefficients"""


def amp2response(
    amps: InputPathType,
    mask: InputPathType,
    directions_: InputPathType,
    response: str,
    isotropic: bool = False,
    noconstraint: bool = False,
    directions: InputPathType | None = None,
    shells: list[float] | None = None,
    lmax: list[int] | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Amp2responseConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Amp2responseOutputs:
    """
    Estimate response function coefficients based on the DWI signal in single-fibre
    voxels.
    
    This command uses the image data from all selected single-fibre voxels
    concurrently, rather than simply averaging their individual spherical
    harmonic coefficients. It also ensures that the response function is
    non-negative, and monotonic (i.e. its amplitude must increase from the fibre
    direction out to the orthogonal plane).
    
    If multi-shell data are provided, and one or more b-value shells are not
    explicitly requested, the command will generate a response function for
    every b-value shell (including b=0 if present).
    
    References:
    
    Smith, R. E.; Dhollander, T. & Connelly, A. Constrained linear least squares
    estimation of anisotropic response function for spherical deconvolution.
    ISMRM Workshop on Breaking the Barriers of Diffusion MRI, 23.
    
    Author: Robert E. Smith (robert.smith@florey.edu.au) and J-Donald Tournier
    (jdtournier@gmail.com)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/amp2response.html
    
    Args:
        amps: the amplitudes image.
        mask: the mask containing the voxels from which to estimate the\
            response function.
        directions_: a 4D image containing the estimated fibre directions.
        response: the output zonal spherical harmonic coefficients.
        isotropic: estimate an isotropic response function (lmax=0 for all\
            shells).
        noconstraint: disable the non-negativity and monotonicity constraints.
        directions: provide an external text file containing the directions\
            along which the amplitudes are sampled.
        shells: specify one or more b-values to use during processing, as a\
            comma-separated list of the desired approximate b-values (b-values are\
            clustered to allow for small deviations). Note that some commands are\
            incompatible with multiple b-values, and will report an error if more\
            than one b-value is provided.\
            WARNING: note that, even though the b=0 volumes are never referred\
            to as shells in the literature, they still have to be explicitly\
            included in the list of b-values as provided to the -shell option!\
            Several algorithms which include the b=0 volumes in their\
            computations may otherwise return an undesired result.
        lmax: specify the maximum harmonic degree of the response function to\
            estimate (can be a comma-separated list for multi-shell data).
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Amp2responseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AMP2RESPONSE_METADATA)
    cargs = []
    cargs.append("amp2response")
    if isotropic:
        cargs.append("-isotropic")
    if noconstraint:
        cargs.append("-noconstraint")
    if directions is not None:
        cargs.extend([
            "-directions",
            execution.input_file(directions)
        ])
    if shells is not None:
        cargs.extend([
            "-shells",
            ",".join(map(str, shells))
        ])
    if lmax is not None:
        cargs.extend([
            "-lmax",
            ",".join(map(str, lmax))
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(amps))
    cargs.append(execution.input_file(mask))
    cargs.append(execution.input_file(directions_))
    cargs.append(response)
    ret = Amp2responseOutputs(
        root=execution.output_file("."),
        response=execution.output_file(response),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AMP2RESPONSE_METADATA",
    "Amp2responseConfig",
    "Amp2responseOutputs",
    "amp2response",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_CREATE_METADATA = Metadata(
    id="5d7086a20f40e1369099258732e008fa1d902dda.boutiques",
    name="volume-create",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class VolumeCreatePlumb:
    """
    set via axis order and spacing/offset.
    """
    axis_order: str
    """a string like 'XYZ' that specifies which index is along which spatial
    dimension"""
    x_spacing: float
    """change in x-coordinate from incrementing the relevant index"""
    y_spacing: float
    """change in y-coordinate from incrementing the relevant index"""
    z_spacing: float
    """change in z-coordinate from incrementing the relevant index"""
    x_offset: float
    """the x-coordinate of the center of the first voxel"""
    y_offset: float
    """the y-coordinate of the center of the first voxel"""
    z_offset: float
    """the z-coordinate of the center of the first voxel"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-plumb")
        cargs.append(self.axis_order)
        cargs.append(str(self.x_spacing))
        cargs.append(str(self.y_spacing))
        cargs.append(str(self.z_spacing))
        cargs.append(str(self.x_offset))
        cargs.append(str(self.y_offset))
        cargs.append(str(self.z_offset))
        return cargs


@dataclasses.dataclass
class VolumeCreateSform:
    """
    set via a nifti sform.
    """
    xi_spacing: float
    """increase in x coordinate from incrementing the i index"""
    xj_spacing: float
    """increase in x coordinate from incrementing the j index"""
    xk_spacing: float
    """increase in x coordinate from incrementing the k index"""
    x_offset: float
    """x coordinate of first voxel"""
    yi_spacing: float
    """increase in y coordinate from incrementing the i index"""
    yj_spacing: float
    """increase in y coordinate from incrementing the j index"""
    yk_spacing: float
    """increase in y coordinate from incrementing the k index"""
    y_offset: float
    """y coordinate of first voxel"""
    zi_spacing: float
    """increase in z coordinate from incrementing the i index"""
    zj_spacing: float
    """increase in z coordinate from incrementing the j index"""
    zk_spacing: float
    """increase in z coordinate from incrementing the k index"""
    z_offset: float
    """z coordinate of first voxel"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-sform")
        cargs.append(str(self.xi_spacing))
        cargs.append(str(self.xj_spacing))
        cargs.append(str(self.xk_spacing))
        cargs.append(str(self.x_offset))
        cargs.append(str(self.yi_spacing))
        cargs.append(str(self.yj_spacing))
        cargs.append(str(self.yk_spacing))
        cargs.append(str(self.y_offset))
        cargs.append(str(self.zi_spacing))
        cargs.append(str(self.zj_spacing))
        cargs.append(str(self.zk_spacing))
        cargs.append(str(self.z_offset))
        return cargs


class VolumeCreateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_create(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_create(
    i_dim: int,
    j_dim: int,
    k_dim: int,
    volume_out: str,
    plumb: VolumeCreatePlumb | None = None,
    sform: VolumeCreateSform | None = None,
    runner: Runner | None = None,
) -> VolumeCreateOutputs:
    """
    Create a blank volume file.
    
    Creates a volume file full of zeros. Exactly one of -plumb or -sform must be
    specified.
    
    Author: Washington University School of Medicin
    
    Args:
        i_dim: length of first dimension.
        j_dim: length of second dimension.
        k_dim: length of third dimension.
        volume_out: the output volume.
        plumb: set via axis order and spacing/offset.
        sform: set via a nifti sform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeCreateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_CREATE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-create")
    cargs.append(str(i_dim))
    cargs.append(str(j_dim))
    cargs.append(str(k_dim))
    cargs.append(volume_out)
    if plumb is not None:
        cargs.extend(plumb.run(execution))
    if sform is not None:
        cargs.extend(sform.run(execution))
    ret = VolumeCreateOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_CREATE_METADATA",
    "VolumeCreateOutputs",
    "VolumeCreatePlumb",
    "VolumeCreateSform",
    "volume_create",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

XTRACT_BLUEPRINT_METADATA = Metadata(
    id="ba39ba249f8c307b2d42d56510e04db2a384a01f.boutiques",
    name="xtract_blueprint",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class XtractBlueprintOutputs(typing.NamedTuple):
    """
    Output object returned when calling `xtract_blueprint(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Output files generated in the specified output folder"""


def xtract_blueprint(
    bpx_folder: str,
    out_folder: str,
    xtract_folder: str,
    seeds_list: str,
    stage: str | None = None,
    gpu_flag: bool = False,
    save_txt_flag: bool = False,
    prefix: str | None = None,
    rois_list: str | None = None,
    stops_file: InputPathType | None = None,
    wtstops_file: InputPathType | None = None,
    tract_list: str | None = None,
    threshold: float | None = 0.001,
    nsamples: float | None = 1000,
    res: float | None = 3,
    ptx_options: InputPathType | None = None,
    runner: Runner | None = None,
) -> XtractBlueprintOutputs:
    """
    Blueprint extraction tool using XTRACT and bedpostx folders.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk
    
    Args:
        bpx_folder: Path to bedpostx folder.
        out_folder: Path to output folder.
        xtract_folder: Path to xtract folder.
        seeds_list: Comma separated list of seeds for which a blueprint is\
            requested.
        stage: What to run. 1:matrix2, 2:blueprint, all:everything (default).
        gpu_flag: Use GPU version.
        save_txt_flag: Save blueprint as txt file (nseed by ntracts) instead of\
            CIFTI.
        prefix: Specify a prefix for the final blueprint filename.
        rois_list: Comma separated list of ROIs (gifti) to restrict seeding\
            (e.g. medial wall masks).
        stops_file: Text file containing line separated list.
        wtstops_file: Text file containing line separated list.
        tract_list: Comma separated list of tracts to include (default = all\
            found under -xtract <folder>).
        threshold: Threshold applied to XTRACT tracts prior to blueprint\
            calculation (default = 0.001, i.e. 0.1% probability).
        nsamples: Number of samples per seed used in tractography (default =\
            1000).
        res: Resolution of matrix2 output (Default = 3 mm).
        ptx_options: Pass extra probtrackx2 options as a text file to override\
            defaults.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `XtractBlueprintOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(XTRACT_BLUEPRINT_METADATA)
    cargs = []
    cargs.append("xtract_blueprint")
    cargs.append("-bpx")
    cargs.append(bpx_folder)
    cargs.append("-out")
    cargs.append(out_folder)
    cargs.append("-xtract")
    cargs.append(xtract_folder)
    cargs.append("-seeds")
    cargs.append(seeds_list)
    cargs.append("-warps")
    cargs.append("[REF]")
    cargs.append("[XTRACT2DIFF]")
    cargs.append("[DIFF2XTRACT]")
    if stage is not None:
        cargs.extend([
            "-stage",
            stage
        ])
    if gpu_flag:
        cargs.append("-gpu")
    if save_txt_flag:
        cargs.append("-savetxt")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if rois_list is not None:
        cargs.extend([
            "-rois",
            rois_list
        ])
    if stops_file is not None:
        cargs.extend([
            "-stops",
            execution.input_file(stops_file)
        ])
    if wtstops_file is not None:
        cargs.extend([
            "-wtstops",
            execution.input_file(wtstops_file)
        ])
    if tract_list is not None:
        cargs.extend([
            "-tract_list",
            tract_list
        ])
    if threshold is not None:
        cargs.extend([
            "-thr",
            str(threshold)
        ])
    if nsamples is not None:
        cargs.extend([
            "-nsamples",
            str(nsamples)
        ])
    if res is not None:
        cargs.extend([
            "-res",
            str(res)
        ])
    if ptx_options is not None:
        cargs.extend([
            "-ptx_options",
            execution.input_file(ptx_options)
        ])
    ret = XtractBlueprintOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(out_folder + "/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "XTRACT_BLUEPRINT_METADATA",
    "XtractBlueprintOutputs",
    "xtract_blueprint",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ROI_CORR_MAT_METADATA = Metadata(
    id="93306081b2aa4d941532f5a06e179689e35bced4.boutiques",
    name="@ROI_Corr_Mat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VRoiCorrMatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__roi_corr_mat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    matrix_1d: OutputPathType
    """Correlation matrix in .1D format"""
    matrix_brick: OutputPathType
    """Correlation matrix in .BRIK format"""


def v__roi_corr_mat(
    runner: Runner | None = None,
) -> VRoiCorrMatOutputs:
    """
    Script to produce an NxN ROI correlation matrix of N ROIs.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@ROI_Corr_Mat.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VRoiCorrMatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ROI_CORR_MAT_METADATA)
    cargs = []
    cargs.append("@ROI_Corr_Mat")
    cargs.append("<-ts")
    cargs.append("TimeSeriesVol>")
    cargs.append("<-roi")
    cargs.append("ROIVol>")
    cargs.append("<-prefix")
    cargs.append("output>")
    cargs.append("[<-roisel")
    cargs.append("ROISEL>]")
    cargs.append("[-zval]")
    cargs.append("[-mat")
    cargs.append("FULL,")
    cargs.append("TRI,")
    cargs.append("TRI_ND]")
    cargs.append("[-verb]")
    cargs.append("[-dirty]")
    ret = VRoiCorrMatOutputs(
        root=execution.output_file("."),
        matrix_1d=execution.output_file("[output]_matrix.1D"),
        matrix_brick=execution.output_file("[output]_matrix.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VRoiCorrMatOutputs",
    "V__ROI_CORR_MAT_METADATA",
    "v__roi_corr_mat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FABBER_QBOLD_METADATA = Metadata(
    id="790aded0ed85b0dafc8a88514179c6783ce215e6.boutiques",
    name="fabber_qbold",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FabberQboldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fabber_qbold(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    paramnames_file: OutputPathType
    """File containing the names of the model parameters"""
    model_fit_file: OutputPathType
    """4D volume of the model prediction"""
    residuals_file: OutputPathType
    """4D volume of the residuals"""
    model_extras_file: OutputPathType
    """Additional model-specific timeseries data"""
    mvn_file: OutputPathType
    """File containing the final MVN distributions"""
    mean_file: OutputPathType
    """File containing the parameter means"""
    std_file: OutputPathType
    """File containing the parameter standard deviations"""
    var_file: OutputPathType
    """File containing the parameter variances"""
    zstat_file: OutputPathType
    """File containing the parameter Zstats"""
    noise_mean_file: OutputPathType
    """File containing the noise means"""
    noise_std_file: OutputPathType
    """File containing the noise standard deviations"""
    free_energy_file: OutputPathType
    """File containing the free energy, if calculated"""
    logfile: OutputPathType
    """Logfile of the execution"""


def fabber_qbold(
    runner: Runner | None = None,
) -> FabberQboldOutputs:
    """
    Fabber - a flexible BaYesian modeling framework for FMRI and MRI analysis.
    
    Author: FSL
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fabber
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FabberQboldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FABBER_QBOLD_METADATA)
    cargs = []
    cargs.append("fabber")
    cargs.append("[--listmethods]")
    cargs.append("[--listmodels]")
    cargs.append("[--listparams]")
    cargs.append("[--descparams]")
    cargs.append("[--listoutputs]")
    cargs.append("[--evaluate]")
    cargs.append("[--evaluate-params]")
    cargs.append("[--evaluate-nt]")
    cargs.append("[--simple-output]")
    cargs.append("[--output]")
    cargs.append("[--overwrite]")
    cargs.append("[--link-to-latest]")
    cargs.append("[--method]")
    cargs.append("[--model]")
    cargs.append("[--loadmodels]")
    cargs.append("[--data]")
    cargs.append("[--data<n>]")
    cargs.append("[--data-order]")
    cargs.append("[--mask]")
    cargs.append("[--mt<n>]")
    cargs.append("[--suppdata]")
    cargs.append("[--dump-param-names]")
    cargs.append("[--save-model-fit]")
    cargs.append("[--save-residuals]")
    cargs.append("[--save-model-extras]")
    cargs.append("[--save-mvn]")
    cargs.append("[--save-mean]")
    cargs.append("[--save-std]")
    cargs.append("[--save-var]")
    cargs.append("[--save-zstat]")
    cargs.append("[--save-noise-mean]")
    cargs.append("[--save-noise-std]")
    cargs.append("[--save-free-energy]")
    cargs.append("[--optfile]")
    cargs.append("[--debug]")
    ret = FabberQboldOutputs(
        root=execution.output_file("."),
        paramnames_file=execution.output_file("[OUTPUT_DIR]/paramnames.txt"),
        model_fit_file=execution.output_file("[OUTPUT_DIR]/model_fit.nii.gz"),
        residuals_file=execution.output_file("[OUTPUT_DIR]/residuals.nii.gz"),
        model_extras_file=execution.output_file("[OUTPUT_DIR]/model_extras.nii.gz"),
        mvn_file=execution.output_file("[OUTPUT_DIR]/mvn.nii.gz"),
        mean_file=execution.output_file("[OUTPUT_DIR]/mean.nii.gz"),
        std_file=execution.output_file("[OUTPUT_DIR]/std.nii.gz"),
        var_file=execution.output_file("[OUTPUT_DIR]/var.nii.gz"),
        zstat_file=execution.output_file("[OUTPUT_DIR]/zstat.nii.gz"),
        noise_mean_file=execution.output_file("[OUTPUT_DIR]/noise_mean.nii.gz"),
        noise_std_file=execution.output_file("[OUTPUT_DIR]/noise_std.nii.gz"),
        free_energy_file=execution.output_file("[OUTPUT_DIR]/free_energy.nii.gz"),
        logfile=execution.output_file("[OUTPUT_DIR]/logfile.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FABBER_QBOLD_METADATA",
    "FabberQboldOutputs",
    "fabber_qbold",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FABBER_DCE_METADATA = Metadata(
    id="86a1dfb3ab7189eb7050b42d679d660cf3289061.boutiques",
    name="fabber_dce",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FabberDceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fabber_dce(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Files generated by Fabber DCE"""


def fabber_dce(
    forward_model: str,
    inference_method: str,
    input_data: InputPathType,
    output_directory: str,
    runner: Runner | None = None,
) -> FabberDceOutputs:
    """
    Fabber DCE analysis tool for model-based analysis of dynamic contrast-enhanced
    imaging data.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fabber-core.readthedocs.io/
    
    Args:
        forward_model: Forward model to use.
        inference_method: Inference method to use.
        input_data: Single input data file.
        output_directory: Directory for output files (including logfile).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FabberDceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FABBER_DCE_METADATA)
    cargs = []
    cargs.append("fabber")
    cargs.extend([
        "--model",
        forward_model
    ])
    cargs.extend([
        "--method",
        inference_method
    ])
    cargs.extend([
        "--data",
        execution.input_file(input_data)
    ])
    cargs.append("--output")
    cargs.extend([
        "--output",
        output_directory
    ])
    cargs.append("[OPTIONS]")
    ret = FabberDceOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(output_directory + "/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FABBER_DCE_METADATA",
    "FabberDceOutputs",
    "fabber_dce",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPEC_FILE_RELOCATE_METADATA = Metadata(
    id="343df0156cccccb7732447a63224c25638129722.boutiques",
    name="spec-file-relocate",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SpecFileRelocateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `spec_file_relocate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def spec_file_relocate(
    input_spec: str,
    output_spec: str,
    runner: Runner | None = None,
) -> SpecFileRelocateOutputs:
    """
    Recreate spec file in new location.
    
    Spec files contain internal relative paths, such that moving or copying a
    spec file will cause it to lose track of the files it refers to. This
    command makes a modified copy of the spec file, changing the relative paths
    to refer to the new relative locations of the files.
    
    Author: Washington University School of Medicin
    
    Args:
        input_spec: the spec file to use.
        output_spec: output - the new spec file to create.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SpecFileRelocateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPEC_FILE_RELOCATE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-spec-file-relocate")
    cargs.append(input_spec)
    cargs.append(output_spec)
    ret = SpecFileRelocateOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPEC_FILE_RELOCATE_METADATA",
    "SpecFileRelocateOutputs",
    "spec_file_relocate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLINTERLEAVE_METADATA = Metadata(
    id="0233ea4118d65eb47c310757e7da308f61ff294e.boutiques",
    name="fslinterleave",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslinterleaveOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslinterleave(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    interleaved_output: OutputPathType
    """Interleaved output image"""


def fslinterleave(
    infile1: InputPathType,
    infile2: InputPathType,
    outfile: str,
    reverse_slice_order_flag: bool = False,
    runner: Runner | None = None,
) -> FslinterleaveOutputs:
    """
    Interleaves two input images slice-by-slice to produce an output image.
    
    Author: FMRIB Software Library (FSL)
    
    URL: https://fsl.fmrib.ox.ac.uk
    
    Args:
        infile1: First input image.
        infile2: Second input image.
        outfile: Output interleaved image.
        reverse_slice_order_flag: Reverse slice order.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslinterleaveOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLINTERLEAVE_METADATA)
    cargs = []
    cargs.append("fslinterleave")
    cargs.append(execution.input_file(infile1))
    cargs.append(execution.input_file(infile2))
    cargs.append(outfile)
    if reverse_slice_order_flag:
        cargs.append("-i")
    ret = FslinterleaveOutputs(
        root=execution.output_file("."),
        interleaved_output=execution.output_file(outfile + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLINTERLEAVE_METADATA",
    "FslinterleaveOutputs",
    "fslinterleave",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_COMPONENTS_TO_FRAMES_METADATA = Metadata(
    id="e45133eca7d56860fb9bc6a395802c220898015d.boutiques",
    name="volume-components-to-frames",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class VolumeComponentsToFramesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_components_to_frames(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the input volume converted to multiple frames of scalar type"""


def volume_components_to_frames(
    input_: InputPathType,
    output: str,
    runner: Runner | None = None,
) -> VolumeComponentsToFramesOutputs:
    """
    Convert rgb/complex volume to frames.
    
    RGB and complex datatypes are not always well supported, this command allows
    separating them into standard subvolumes for better support.
    
    Author: Washington University School of Medicin
    
    Args:
        input_: the RGB/complex-type volume.
        output: the input volume converted to multiple frames of scalar type.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeComponentsToFramesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_COMPONENTS_TO_FRAMES_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-components-to-frames")
    cargs.append(execution.input_file(input_))
    cargs.append(output)
    ret = VolumeComponentsToFramesOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_COMPONENTS_TO_FRAMES_METADATA",
    "VolumeComponentsToFramesOutputs",
    "volume_components_to_frames",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_DSET_METADATA = Metadata(
    id="c8a3a3600863809bdcfbd75d710a1a9b340b7a80.boutiques",
    name="ConvertDset",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ConvertDsetOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_dset(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    converted_dataset: OutputPathType | None
    """Converted dataset output"""


def convert_dset(
    output_type: list[typing.Literal["niml_asc", "niml_bi", "1D", "1Dp", "1Dpt", "gii", "gii_asc", "gii_b64", "gii_b64gz", "1D_stderr", "1D_stdout", "niml_stderr", "niml_stdout", "1Dp_stdout", "1Dp_stderr", "1Dpt_stdout", "1Dpt_stderr"]],
    input_dataset: InputPathType,
    input_type: typing.Literal["niml", "1D", "dx"] | None = None,
    output_prefix: str | None = None,
    runner: Runner | None = None,
) -> ConvertDsetOutputs:
    """
    Converts a surface dataset from one format to another.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/ConvertDset.html
    
    Args:
        output_type: Type of output datasets.
        input_dataset: Input dataset to be converted.
        input_type: Type of input datasets.
        output_prefix: Output prefix for dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertDsetOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_DSET_METADATA)
    cargs = []
    cargs.append("ConvertDset")
    cargs.extend([
        "-o_",
        *output_type
    ])
    cargs.append("-input")
    cargs.extend([
        "-input",
        execution.input_file(input_dataset)
    ])
    if input_type is not None:
        cargs.extend([
            "-i_",
            input_type
        ])
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    cargs.append("[MANDATORY_PARAMS]")
    cargs.append("[OPTIONAL_PARAMS]")
    ret = ConvertDsetOutputs(
        root=execution.output_file("."),
        converted_dataset=execution.output_file(output_prefix) if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_DSET_METADATA",
    "ConvertDsetOutputs",
    "convert_dset",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TORTOISETO_HERE_METADATA = Metadata(
    id="face4ad09f678714416dfda6cb399110cbb37e83.boutiques",
    name="3dTORTOISEtoHere",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTortoisetoHereOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tortoiseto_here(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dt_file: OutputPathType
    """Output AFNI-style DT file with the following ordering of the 6 bricks:
    Dxx, Dxy, Dyy, Dxz, Dyz, Dzz."""


def v_3d_tortoiseto_here(
    dt_tort: InputPathType,
    prefix: str,
    scale_factor: float | None = None,
    flip_x: bool = False,
    flip_y: bool = False,
    flip_z: bool = False,
    runner: Runner | None = None,
) -> V3dTortoisetoHereOutputs:
    """
    Convert standard TORTOISE DTs (diagonal-first format) to standard AFNI (lower
    triangular, row-wise) format.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTORTOISEtoHere.html
    
    Args:
        dt_tort: Diffusion tensor file with six bricks of DT components ordered\
            in the TORTOISE manner (Dxx, Dyy, Dzz, Dxy, Dxz, Dyz).
        prefix: Output file name prefix. Will have N+1 bricks when GRADFILE has\
            N rows of gradients.
        scale_factor: Optional switch to rescale the DT elements, dividing by a\
            number X>0.
        flip_x: Change sign of the first element of (inner) eigenvectors.
        flip_y: Change sign of the second element of (inner) eigenvectors.
        flip_z: Change sign of the third element of (inner) eigenvectors.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTortoisetoHereOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TORTOISETO_HERE_METADATA)
    cargs = []
    cargs.append("3dTORTOISEtoHere")
    cargs.append("-dt_tort")
    cargs.extend([
        "-dt_tort",
        execution.input_file(dt_tort)
    ])
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        prefix
    ])
    if scale_factor is not None:
        cargs.extend([
            "-scale_fac",
            str(scale_factor)
        ])
    if flip_x:
        cargs.append("-flip_x")
    if flip_y:
        cargs.append("-flip_y")
    if flip_z:
        cargs.append("-flip_z")
    ret = V3dTortoisetoHereOutputs(
        root=execution.output_file("."),
        output_dt_file=execution.output_file(prefix + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTortoisetoHereOutputs",
    "V_3D_TORTOISETO_HERE_METADATA",
    "v_3d_tortoiseto_here",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_SETUP_GROUP_IN_CORR_METADATA = Metadata(
    id="02e5c2cd54cdb6f0011268c1d7356b9a0a55be7c.boutiques",
    name="3dSetupGroupInCorr",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dSetupGroupInCorrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_setup_group_in_corr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    niml_file: OutputPathType
    """Text file containing the header information describing the data file."""
    data_file: OutputPathType
    """Data file containing all the time series from all the datasets."""


def v_3d_setup_group_in_corr(
    datasets: list[InputPathType],
    runner: Runner | None = None,
) -> V3dSetupGroupInCorrOutputs:
    """
    Pre-process a collection of AFNI 3D+time datasets for use with Group InstaCorr.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dSetupGroupInCorr.html
    
    Args:
        datasets: AFNI 3D+time datasets to be processed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dSetupGroupInCorrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_SETUP_GROUP_IN_CORR_METADATA)
    cargs = []
    cargs.append("3dSetupGroupInCorr")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in datasets])
    ret = V3dSetupGroupInCorrOutputs(
        root=execution.output_file("."),
        niml_file=execution.output_file("[PREFIX].grpincorr.niml"),
        data_file=execution.output_file("[PREFIX].grpincorr.data"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dSetupGroupInCorrOutputs",
    "V_3D_SETUP_GROUP_IN_CORR_METADATA",
    "v_3d_setup_group_in_corr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_PQ_SCRIPT_PY_METADATA = Metadata(
    id="2e44222ffa661bbbd3fe92eb28fb4f0520058b65.boutiques",
    name="make_pq_script.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class MakePqScriptPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_pq_script_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    script: OutputPathType
    """Generated output script"""


def make_pq_script_py(
    dataset: InputPathType,
    brick_index: float,
    mask: InputPathType,
    out_script: str,
    runner: Runner | None = None,
) -> MakePqScriptPyOutputs:
    """
    Creates a script to compute p-value and q-value curves.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/make_pq_script.py.html
    
    Args:
        dataset: Input dataset (no sub-brick selectors).
        brick_index: Volume sub-brick for specific t-stat.
        mask: Mask volume dataset.
        out_script: Name for output script to write.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakePqScriptPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_PQ_SCRIPT_PY_METADATA)
    cargs = []
    cargs.append("make_pq_script.py")
    cargs.append(execution.input_file(dataset))
    cargs.append(str(brick_index))
    cargs.append(execution.input_file(mask))
    cargs.append(out_script)
    ret = MakePqScriptPyOutputs(
        root=execution.output_file("."),
        script=execution.output_file(out_script),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_PQ_SCRIPT_PY_METADATA",
    "MakePqScriptPyOutputs",
    "make_pq_script_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFNI_SYSTEM_CHECK_PY_METADATA = Metadata(
    id="561605c39b2a296b2c61c5f34bc02b377a92937a.boutiques",
    name="afni_system_check.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AfniSystemCheckPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `afni_system_check_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def afni_system_check_py(
    runner: Runner | None = None,
) -> AfniSystemCheckPyOutputs:
    """
    Perform various system checks for figuring out AFNI installation issues.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/afni_system_check.py.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AfniSystemCheckPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFNI_SYSTEM_CHECK_PY_METADATA)
    cargs = []
    cargs.append("afni_system_check.py")
    cargs.append("[TERMINAL_OPTS]")
    cargs.append("[ACTION_OPTS]")
    cargs.append("[OTHER_OPTS]")
    ret = AfniSystemCheckPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFNI_SYSTEM_CHECK_PY_METADATA",
    "AfniSystemCheckPyOutputs",
    "afni_system_check_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_PROC_MAP_TO_DTI_METADATA = Metadata(
    id="ee78feae0990bd37d34d68c063edc4b3b4071179.boutiques",
    name="fat_proc_map_to_dti",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatProcMapToDtiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_proc_map_to_dti(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fat_proc_map_to_dti(
    source: InputPathType,
    base: InputPathType,
    prefix: str,
    followers_nn: list[InputPathType] | None = None,
    followers_wsinc5: list[InputPathType] | None = None,
    followers_surf: list[InputPathType] | None = None,
    followers_ndset: list[InputPathType] | None = None,
    followers_spec: list[InputPathType] | None = None,
    matrix: InputPathType | None = None,
    workdir: str | None = None,
    no_cmd_out: bool = False,
    no_clean: bool = False,
    runner: Runner | None = None,
) -> FatProcMapToDtiOutputs:
    """
    A program for mapping data sets into DWI space, suitable for aligning anatomical
    ROI maps or EPI data to a DWI reference volume.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/fat_proc_map_to_dti.html
    
    Args:
        source: T1w volume file (source volume).
        base: DWI reference volume file.
        prefix: Output prefix for files and snapshots.
        followers_nn: Follower data sets with NN interpolation.
        followers_wsinc5: Follower data sets with wsinc5 interpolation.
        followers_surf: Surface follower data sets.
        followers_ndset: NIML follower data sets.
        followers_spec: Spec follower data sets.
        matrix: Pre-made matrix file for transformation.
        workdir: Specify a working directory.
        no_cmd_out: Don't save the command line call of this program.
        no_clean: Do not delete temporary working directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatProcMapToDtiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_PROC_MAP_TO_DTI_METADATA)
    cargs = []
    cargs.append("fat_proc_map_to_dti")
    cargs.extend([
        "-source",
        execution.input_file(source)
    ])
    cargs.extend([
        "-base",
        execution.input_file(base)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if followers_nn is not None:
        cargs.extend([
            "-followers_NN",
            *[execution.input_file(f) for f in followers_nn]
        ])
    if followers_wsinc5 is not None:
        cargs.extend([
            "-followers_wsinc5",
            *[execution.input_file(f) for f in followers_wsinc5]
        ])
    if followers_surf is not None:
        cargs.extend([
            "-followers_surf",
            *[execution.input_file(f) for f in followers_surf]
        ])
    if followers_ndset is not None:
        cargs.extend([
            "-followers_ndset",
            *[execution.input_file(f) for f in followers_ndset]
        ])
    if followers_spec is not None:
        cargs.extend([
            "-followers_spec",
            *[execution.input_file(f) for f in followers_spec]
        ])
    if matrix is not None:
        cargs.extend([
            "-matrix",
            execution.input_file(matrix)
        ])
    if workdir is not None:
        cargs.extend([
            "-workdir",
            workdir
        ])
    if no_cmd_out:
        cargs.append("-no_cmd_out")
    if no_clean:
        cargs.append("-no_clean")
    ret = FatProcMapToDtiOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_PROC_MAP_TO_DTI_METADATA",
    "FatProcMapToDtiOutputs",
    "fat_proc_map_to_dti",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DWI2RESPONSE_METADATA = Metadata(
    id="edddbe80993b644221e1465a2dd0d5c280ed0192.boutiques",
    name="dwi2response",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


class Dwi2responseDhollanderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `Dwi2responseDhollander(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_sfwm: OutputPathType
    """Output single-fibre WM response function text file"""
    out_gm: OutputPathType
    """Output GM response function text file"""
    out_csf: OutputPathType
    """Output CSF response function text file"""


@dataclasses.dataclass
class Dwi2responseDhollander:
    """
    Unsupervised estimation of WM, GM and CSF response functions that does not
    require a T1 image (or segmentation thereof).
    This is an improved version of the Dhollander et al. (2016) algorithm for
    unsupervised estimation of WM, GM and CSF response functions, which includes
    the Dhollander et al. (2019) improvements for single-fibre WM response
    function estimation (prior to this update, the "dwi2response tournier"
    algorithm had been utilised specifically for the single-fibre WM response
    function estimation step).
    """
    input_: InputPathType
    """Input DWI dataset"""
    out_sfwm: str
    """Output single-fibre WM response function text file"""
    out_gm: str
    """Output GM response function text file"""
    out_csf: str
    """Output CSF response function text file"""
    erode: int | None = None
    """Number of erosion passes to apply to initial (whole brain) mask. Set to 0
    to not erode the brain mask. (default: 3)"""
    fa: float | None = None
    """FA threshold for crude WM versus GM-CSF separation. (default: 0.2)"""
    sfwm: float | None = None
    """Final number of single-fibre WM voxels to select, as a percentage of
    refined WM. (default: 0.5 per cent)"""
    gm: float | None = None
    """Final number of GM voxels to select, as a percentage of refined GM.
    (default: 2 per cent)"""
    csf: float | None = None
    """Final number of CSF voxels to select, as a percentage of refined CSF.
    (default: 10 per cent)"""
    wm_algo: typing.Literal["fa", "tax", "tournier"] | None = None
    """Use external dwi2response algorithm for WM single-fibre voxel selection
    (options: fa, tax, tournier) (default: built-in Dhollander 2019)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("dhollander")
        cargs.append(execution.input_file(self.input_))
        cargs.append(self.out_sfwm)
        cargs.append(self.out_gm)
        cargs.append(self.out_csf)
        if self.erode is not None:
            cargs.extend([
                "-erode",
                str(self.erode)
            ])
        if self.fa is not None:
            cargs.extend([
                "-fa",
                str(self.fa)
            ])
        if self.sfwm is not None:
            cargs.extend([
                "-sfwm",
                str(self.sfwm)
            ])
        if self.gm is not None:
            cargs.extend([
                "-gm",
                str(self.gm)
            ])
        if self.csf is not None:
            cargs.extend([
                "-csf",
                str(self.csf)
            ])
        if self.wm_algo is not None:
            cargs.extend([
                "-wm_algo",
                self.wm_algo
            ])
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> Dwi2responseDhollanderOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `Dwi2responseDhollanderOutputs`).
        """
        ret = Dwi2responseDhollanderOutputs(
            root=execution.output_file("."),
            out_sfwm=execution.output_file(self.out_sfwm),
            out_gm=execution.output_file(self.out_gm),
            out_csf=execution.output_file(self.out_csf),
        )
        return ret


class Dwi2responseFaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `Dwi2responseFa(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """The output response function text file"""


@dataclasses.dataclass
class Dwi2responseFa:
    """
    Use the old FA-threshold heuristic for single-fibre voxel selection and
    response function estimation.
    """
    input_: InputPathType
    """The input DWI"""
    output: str
    """The output response function text file"""
    erode: int | None = None
    """Number of brain mask erosion steps to apply prior to threshold (not used
    if mask is provided manually)"""
    number: int | None = None
    """The number of highest-FA voxels to use"""
    threshold: float | None = None
    """Apply a hard FA threshold, rather than selecting the top voxels"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("fa")
        cargs.append(execution.input_file(self.input_))
        cargs.append(self.output)
        if self.erode is not None:
            cargs.extend([
                "-erode",
                str(self.erode)
            ])
        if self.number is not None:
            cargs.extend([
                "-number",
                str(self.number)
            ])
        if self.threshold is not None:
            cargs.extend([
                "-threshold",
                str(self.threshold)
            ])
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> Dwi2responseFaOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `Dwi2responseFaOutputs`).
        """
        ret = Dwi2responseFaOutputs(
            root=execution.output_file("."),
            output=execution.output_file(self.output),
        )
        return ret


class Dwi2responseManualOutputs(typing.NamedTuple):
    """
    Output object returned when calling `Dwi2responseManual(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """Output response function text file"""


@dataclasses.dataclass
class Dwi2responseManual:
    """
    Derive a response function using an input mask image alone (i.e.
    pre-selected voxels).
    """
    input_: InputPathType
    """The input DWI"""
    in_voxels: InputPathType
    """Input voxel selection mask"""
    output: str
    """Output response function text file"""
    dirs: InputPathType | None = None
    """Manually provide the fibre direction in each voxel (a tensor fit will be
    used otherwise)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("manual")
        cargs.append(execution.input_file(self.input_))
        cargs.append(execution.input_file(self.in_voxels))
        cargs.append(self.output)
        if self.dirs is not None:
            cargs.extend([
                "-dirs",
                execution.input_file(self.dirs)
            ])
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> Dwi2responseManualOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `Dwi2responseManualOutputs`).
        """
        ret = Dwi2responseManualOutputs(
            root=execution.output_file("."),
            output=execution.output_file(self.output),
        )
        return ret


class Dwi2responseMsmt5ttOutputs(typing.NamedTuple):
    """
    Output object returned when calling `Dwi2responseMsmt5tt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_wm: OutputPathType
    """Output WM response text file"""
    out_gm: OutputPathType
    """Output GM response text file"""
    out_csf: OutputPathType
    """Output CSF response text file"""


@dataclasses.dataclass
class Dwi2responseMsmt5tt:
    """
    Derive MSMT-CSD tissue response functions based on a co-registered
    five-tissue-type (5TT) image.
    """
    input_: InputPathType
    """The input DWI"""
    in_5tt: InputPathType
    """Input co-registered 5TT image"""
    out_wm: str
    """Output WM response text file"""
    out_gm: str
    """Output GM response text file"""
    out_csf: str
    """Output CSF response text file"""
    dirs: InputPathType | None = None
    """Manually provide the fibre direction in each voxel (a tensor fit will be
    used otherwise)"""
    fa: float | None = None
    """Upper fractional anisotropy threshold for GM and CSF voxel selection
    (default: 0.2)"""
    pvf: float | None = None
    """Partial volume fraction threshold for tissue voxel selection (default:
    0.95)"""
    wm_algo: typing.Literal["fa", "tax", "tournier"] | None = None
    """algorithm dwi2response algorithm to use for WM single-fibre voxel
    selection (options: fa, tax, tournier; default: tournier)"""
    sfwm_fa_threshold: float | None = None
    """Sets -wm_algo to fa and allows to specify a hard FA threshold for
    single-fibre WM voxels, which is passed to the -threshold option of the fa
    algorithm (warning: overrides -wm_algo option)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("msmt_5tt")
        cargs.append(execution.input_file(self.input_))
        cargs.append(execution.input_file(self.in_5tt))
        cargs.append(self.out_wm)
        cargs.append(self.out_gm)
        cargs.append(self.out_csf)
        if self.dirs is not None:
            cargs.extend([
                "-dirs",
                execution.input_file(self.dirs)
            ])
        if self.fa is not None:
            cargs.extend([
                "-fa",
                str(self.fa)
            ])
        if self.pvf is not None:
            cargs.extend([
                "-pvf",
                str(self.pvf)
            ])
        if self.wm_algo is not None:
            cargs.extend([
                "-wm_algo",
                self.wm_algo
            ])
        if self.sfwm_fa_threshold is not None:
            cargs.extend([
                "-sfwm_fa_threshold",
                str(self.sfwm_fa_threshold)
            ])
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> Dwi2responseMsmt5ttOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `Dwi2responseMsmt5ttOutputs`).
        """
        ret = Dwi2responseMsmt5ttOutputs(
            root=execution.output_file("."),
            out_wm=execution.output_file(self.out_wm),
            out_gm=execution.output_file(self.out_gm),
            out_csf=execution.output_file(self.out_csf),
        )
        return ret


class Dwi2responseTaxOutputs(typing.NamedTuple):
    """
    Output object returned when calling `Dwi2responseTax(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """The output response function text file"""


@dataclasses.dataclass
class Dwi2responseTax:
    """
    Use the Tax et al. (2014) recursive calibration algorithm for single-fibre
    voxel selection and response function estimation.
    """
    input_: InputPathType
    """The input DWI"""
    output: str
    """The output response function text file"""
    peak_ratio: float | None = None
    """Second-to-first-peak amplitude ratio threshold"""
    max_iters: int | None = None
    """Maximum number of iterations"""
    convergence: float | None = None
    """Percentile change in any RF coefficient required to continue iterating"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("tax")
        cargs.append(execution.input_file(self.input_))
        cargs.append(self.output)
        if self.peak_ratio is not None:
            cargs.extend([
                "-peak_ratio",
                str(self.peak_ratio)
            ])
        if self.max_iters is not None:
            cargs.extend([
                "-max_iters",
                str(self.max_iters)
            ])
        if self.convergence is not None:
            cargs.extend([
                "-convergence",
                str(self.convergence)
            ])
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> Dwi2responseTaxOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `Dwi2responseTaxOutputs`).
        """
        ret = Dwi2responseTaxOutputs(
            root=execution.output_file("."),
            output=execution.output_file(self.output),
        )
        return ret


class Dwi2responseTournierOutputs(typing.NamedTuple):
    """
    Output object returned when calling `Dwi2responseTournier(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """The output response function text file"""


@dataclasses.dataclass
class Dwi2responseTournier:
    """
    Use the Tournier et al. (2013) iterative algorithm for single-fibre voxel
    selection and response function estimation.
    """
    input_: InputPathType
    """The input DWI"""
    output: str
    """The output response function text file"""
    number: int | None = None
    """Number of single-fibre voxels to use when calculating response
    function"""
    iter_voxels: int | None = None
    """Number of single-fibre voxels to select when preparing for the next
    iteration (default = 10 x value given in -number)"""
    dilate: int | None = None
    """Number of mask dilation steps to apply when deriving voxel mask to test
    in the next iteration"""
    max_iters: int | None = None
    """Maximum number of iterations"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("tournier")
        cargs.append(execution.input_file(self.input_))
        cargs.append(self.output)
        if self.number is not None:
            cargs.extend([
                "-number",
                str(self.number)
            ])
        if self.iter_voxels is not None:
            cargs.extend([
                "-iter_voxels",
                str(self.iter_voxels)
            ])
        if self.dilate is not None:
            cargs.extend([
                "-dilate",
                str(self.dilate)
            ])
        if self.max_iters is not None:
            cargs.extend([
                "-max_iters",
                str(self.max_iters)
            ])
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> Dwi2responseTournierOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `Dwi2responseTournierOutputs`).
        """
        ret = Dwi2responseTournierOutputs(
            root=execution.output_file("."),
            output=execution.output_file(self.output),
        )
        return ret


@dataclasses.dataclass
class Dwi2responseFslgrad:
    """
    Provide the diffusion gradient table in FSL bvecs/bvals format.
    """
    bvecs: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    bvals: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-fslgrad")
        cargs.append(execution.input_file(self.bvecs))
        cargs.append(execution.input_file(self.bvals))
        return cargs


@dataclasses.dataclass
class Dwi2responseConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Dwi2responseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dwi2response(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    algorithm: typing.Union[Dwi2responseDhollanderOutputs, Dwi2responseFaOutputs, Dwi2responseManualOutputs, Dwi2responseMsmt5ttOutputs, Dwi2responseTaxOutputs, Dwi2responseTournierOutputs]
    """Outputs from `Dwi2responseDhollander` or `Dwi2responseFa` or
    `Dwi2responseManual` or `Dwi2responseMsmt5tt` or `Dwi2responseTax` or
    `Dwi2responseTournier`."""


def dwi2response(
    algorithm: typing.Union[Dwi2responseDhollander, Dwi2responseFa, Dwi2responseManual, Dwi2responseMsmt5tt, Dwi2responseTax, Dwi2responseTournier],
    grad: InputPathType | None = None,
    fslgrad: Dwi2responseFslgrad | None = None,
    mask: InputPathType | None = None,
    voxels: str | None = None,
    shells: list[int] | None = None,
    lmax: list[int] | None = None,
    nocleanup: bool = False,
    scratch: str | None = None,
    continue_: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Dwi2responseConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Dwi2responseOutputs:
    """
    Estimate response function(s) for spherical deconvolution.
    dwi2response offers different algorithms for performing various types of
    response function estimation. The name of the algorithm must appear as the
    first argument on the command-line after ‘dwi2response’. The subsequent
    arguments and options depend on the particular algorithm being invoked.
    Each algorithm available has its own help page, including necessary
    references; e.g. to see the help page of the 'fa' algorithm, type
    'dwi2response fa'.
    
    Author: Robert E. Smith (robert.smith@florey.edu.au) & Thijs Dhollander
    (thijs.dhollander@gmail.com)
    
    URL:
    https://mrtrix.readthedocs.io/en/3.0.4/reference/commands/dwi2response.html
    
    Args:
        algorithm: Select the algorithm to be used to complete the script\
            operation; additional details and options become available once an\
            algorithm is nominated. Options are: dhollander, fa, manual, msmt_5tt,\
            tax, tournier.
        grad: Provide the diffusion gradient table in MRtrix format.
        fslgrad: Provide the diffusion gradient table in FSL bvecs/bvals format.
        mask: Only process voxels within the specified binary brain mask image.
        voxels: Output an image showing the final voxel selection(s).
        shells: b-value(s) to use in response function estimation\
            (comma-separated list in case of multiple b-values, b=0 must be\
            included explicitly).
        lmax: maximum harmonic degree(s) for response function estimation\
            (comma-separated list in case of multiple b-values).
        nocleanup: do not delete intermediate files during script execution,\
            and do not delete scratch directory at script completion.
        scratch: manually specify the path in which to generate the scratch\
            directory.
        continue_: continue the script from a previous execution; must provide\
            the scratch directory path, and the name of the last\
            successfully-generated file.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Dwi2responseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DWI2RESPONSE_METADATA)
    cargs = []
    cargs.append("dwi2response")
    cargs.extend(algorithm.run(execution))
    if grad is not None:
        cargs.extend([
            "-grad",
            execution.input_file(grad)
        ])
    if fslgrad is not None:
        cargs.extend(fslgrad.run(execution))
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if voxels is not None:
        cargs.extend([
            "-voxels",
            voxels
        ])
    if shells is not None:
        cargs.extend([
            "-shells",
            ",".join(map(str, shells))
        ])
    if lmax is not None:
        cargs.extend([
            "-lmax",
            ",".join(map(str, lmax))
        ])
    if nocleanup:
        cargs.append("-nocleanup")
    if scratch is not None:
        cargs.extend([
            "-scratch",
            scratch
        ])
    if continue_ is not None:
        cargs.extend([
            "-continue",
            continue_
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    ret = Dwi2responseOutputs(
        root=execution.output_file("."),
        algorithm=algorithm.outputs(execution),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DWI2RESPONSE_METADATA",
    "Dwi2responseConfig",
    "Dwi2responseDhollander",
    "Dwi2responseDhollanderOutputs",
    "Dwi2responseFa",
    "Dwi2responseFaOutputs",
    "Dwi2responseFslgrad",
    "Dwi2responseManual",
    "Dwi2responseManualOutputs",
    "Dwi2responseMsmt5tt",
    "Dwi2responseMsmt5ttOutputs",
    "Dwi2responseOutputs",
    "Dwi2responseTax",
    "Dwi2responseTaxOutputs",
    "Dwi2responseTournier",
    "Dwi2responseTournierOutputs",
    "dwi2response",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PRELUDE_METADATA = Metadata(
    id="0867c14affae753235846fc390d99d8e1894bfa4.boutiques",
    name="prelude",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PreludeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `prelude(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    unwrapped_phase_output: OutputPathType
    """Unwrapped phase output file"""
    saved_mask_volume: OutputPathType
    """Saved mask volume file"""
    saved_raw_phase_output: OutputPathType
    """Saved raw phase output file"""
    saved_area_labels_output: OutputPathType
    """Saved area labels output file"""


def prelude(
    runner: Runner | None = None,
) -> PreludeOutputs:
    """
    Phase Region Expanding Labeller for Unwrapping Discrete Estimates.
    
    Author: University of Oxford (Mark Jenkinson)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/PRELUDE
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PreludeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PRELUDE_METADATA)
    cargs = []
    cargs.append("prelude")
    cargs.append("[1")
    cargs.append("or")
    cargs.append("more]")
    cargs.append("[OPTIONS]")
    ret = PreludeOutputs(
        root=execution.output_file("."),
        unwrapped_phase_output=execution.output_file("[OUTPUT_UNWRAP].nii.gz"),
        saved_mask_volume=execution.output_file("[SAVE_MASK].nii.gz"),
        saved_raw_phase_output=execution.output_file("[SAVE_RAW_PHASE].nii.gz"),
        saved_area_labels_output=execution.output_file("[SAVE_LABELS].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PRELUDE_METADATA",
    "PreludeOutputs",
    "prelude",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

COLUMN_CAT_METADATA = Metadata(
    id="27786d9bfa7cd4bd2749d24c7c42d600bd9a2b10.boutiques",
    name="column_cat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ColumnCatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `column_cat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Redirect output of concatenation to a file"""


def column_cat(
    input_files: list[InputPathType],
    line_number: float | None = None,
    separator_string: str | None = None,
    runner: Runner | None = None,
) -> ColumnCatOutputs:
    """
    Catenate files horizontally. Each line of output is the concatenation of each
    current line from the input files, all on the same line, separated by a space or
    a user-defined separator.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/column_cat.html
    
    Args:
        input_files: Input files to be concatenated.
        line_number: Print only the specified line number (1-based).
        separator_string: Use the specified string as a separator between\
            columns.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ColumnCatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(COLUMN_CAT_METADATA)
    cargs = []
    cargs.append("column_cat")
    if line_number is not None:
        cargs.extend([
            "-line",
            str(line_number)
        ])
    if separator_string is not None:
        cargs.extend([
            "-sep",
            separator_string
        ])
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = ColumnCatOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("output_file.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "COLUMN_CAT_METADATA",
    "ColumnCatOutputs",
    "column_cat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFNI_SKELETON_PY_METADATA = Metadata(
    id="be79df838923509767e66b6dfa3212abfc496637.boutiques",
    name="afni_skeleton.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AfniSkeletonPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `afni_skeleton_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def afni_skeleton_py(
    infiles: list[InputPathType] | None = None,
    help_: bool = False,
    hist: bool = False,
    ver: bool = False,
    runner: Runner | None = None,
) -> AfniSkeletonPyOutputs:
    """
    Skeleton of a basic python program example.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/afni_skeleton.py.html
    
    Args:
        infiles: Specify input files.
        help_: Show help message.
        hist: Show the revision history.
        ver: Show the version number.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AfniSkeletonPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFNI_SKELETON_PY_METADATA)
    cargs = []
    cargs.append("afni_skeleton.py")
    if infiles is not None:
        cargs.extend([execution.input_file(f) for f in infiles])
    if help_:
        cargs.append("-help")
    if hist:
        cargs.append("-hist")
    if ver:
        cargs.append("-ver")
    ret = AfniSkeletonPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFNI_SKELETON_PY_METADATA",
    "AfniSkeletonPyOutputs",
    "afni_skeleton_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TCAT_METADATA = Metadata(
    id="ac1029ce7034504c2ac9eb3016c85a214df41936.boutiques",
    name="3dTcat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTcatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tcat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output image file name."""
    out_file_: OutputPathType
    """Output file."""


def v_3d_tcat(
    in_files: InputPathType,
    rlt: typing.Literal["", "+", "++"] | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    verbose: bool = False,
    runner: Runner | None = None,
) -> V3dTcatOutputs:
    """
    Concatenate sub-bricks from input datasets into one big 3D+time dataset.
    TODO Replace InputMultiPath in_files with Traits.List, if possible. Current
    version adds extra whitespace.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTcat.html
    
    Args:
        in_files: Input file to 3dtcat.
        rlt: '' or '+' or '++'. Remove linear trends in each voxel time series\
            loaded from each input dataset, separately. option -rlt removes the\
            least squares fit of 'a+b*t' to each voxel time series. option -rlt+\
            adds dataset mean back in. option -rlt++ adds overall mean of all\
            dataset timeseries back in.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        verbose: Print out some verbose output as the program.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTcatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TCAT_METADATA)
    cargs = []
    cargs.append("3dTcat")
    if rlt is not None:
        cargs.extend([
            "-rlt",
            rlt
        ])
    cargs.append(execution.input_file(in_files))
    cargs.append("[OUT_FILE]")
    if outputtype is not None:
        cargs.append(outputtype)
    if verbose:
        cargs.append("-verb")
    ret = V3dTcatOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_files).name + "_tcat"),
        out_file_=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTcatOutputs",
    "V_3D_TCAT_METADATA",
    "v_3d_tcat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_LOCAL_PV_METADATA = Metadata(
    id="5df8cc09196eb6e730189ac4f20e1ba919667117.boutiques",
    name="3dLocalPV",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dLocalPvOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_local_pv(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    svd_vector_result: OutputPathType
    """SVD vector result dataset"""
    second_principal_vector: OutputPathType
    """Second principal vector dataset"""
    singular_value: OutputPathType
    """Singular value at each voxel dataset"""


def v_3d_local_pv(
    input_dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dLocalPvOutputs:
    """
    Computes the Singular Value Decomposition (SVD) of the time series from a
    neighborhood of each voxel in a 3D+time dataset, which serves as a smoothing
    method for the dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dLocalPV.html
    
    Args:
        input_dataset: Input time series dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dLocalPvOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_LOCAL_PV_METADATA)
    cargs = []
    cargs.append("3dLocalPV")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_dataset))
    ret = V3dLocalPvOutputs(
        root=execution.output_file("."),
        svd_vector_result=execution.output_file("[PREFIX].nii.gz"),
        second_principal_vector=execution.output_file("[PREFIX2].nii.gz"),
        singular_value=execution.output_file("[EVPREFIX].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dLocalPvOutputs",
    "V_3D_LOCAL_PV_METADATA",
    "v_3d_local_pv",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__UPDATE_AFNI_BINARIES_METADATA = Metadata(
    id="1188231a95870386895c303bd78dc5e7a691fcb6.boutiques",
    name="@update.afni.binaries",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VUpdateAfniBinariesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__update_afni_binaries(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__update_afni_binaries(
    defaults_flag: bool = False,
    help_flag: bool = False,
    help_sys_progs_flag: bool = False,
    apsearch: str | None = None,
    bindir: str | None = None,
    curl_flag: bool = False,
    do_dotfiles_flag: bool = False,
    do_extras_flag: bool = False,
    echo_flag: bool = False,
    make_backup: str | None = None,
    no_cert_verify_flag: bool = False,
    no_recur_flag: bool = False,
    proto: str | None = None,
    quick_flag: bool = False,
    show_obsoletes_flag: bool = False,
    show_obsoletes_grep_flag: bool = False,
    show_system_progs_flag: bool = False,
    sys_ok_flag: bool = False,
    test_flag: bool = False,
    test_protos_flag: bool = False,
    revert_flag: bool = False,
    local_package: str | None = None,
    prog_list: list[str] | None = None,
    package: str | None = None,
    runner: Runner | None = None,
) -> VUpdateAfniBinariesOutputs:
    """
    Install or update AFNI binaries.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@update.afni.binaries.html
    
    Args:
        defaults_flag: Install current package into abin.
        help_flag: Show this help.
        help_sys_progs_flag: List system programs that block update.
        apsearch: Specify getting apsearch updates.
        bindir: Set AFNI binary directory to ABIN.
        curl_flag: Default to curl instead of wget.
        do_dotfiles_flag: Try to initialize dot files if needed.
        do_extras_flag: Do extra niceties (beyond simple install).
        echo_flag: Turn on shell command echo.
        make_backup: Make a backup of binaries before replacing.
        no_cert_verify_flag: Do not verify the server CA certificate.
        no_recur_flag: Do not download and run new @uab script.
        proto: Access afni host via specified PROTOCOL.
        quick_flag: Quick mode, no fancies.
        show_obsoletes_flag: List any obsolete packages.
        show_obsoletes_grep_flag: List any obsolete packages (easy to grep).
        show_system_progs_flag: Show system programs that do not belong in\
            abin.
        sys_ok_flag: OK to update, even if system progs found.
        test_flag: Just attempt the download and quit.
        test_protos_flag: Test download protocols and exit.
        revert_flag: Revert binaries to previous version.
        local_package: Install local PACKAGE.tgz package.
        prog_list: Install given programs, not whole PACKAGE.
        package: Install distribution package PACKAGE.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VUpdateAfniBinariesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__UPDATE_AFNI_BINARIES_METADATA)
    cargs = []
    cargs.append("@update.afni.binaries")
    if defaults_flag:
        cargs.append("-defaults")
    if help_flag:
        cargs.append("-help")
    if help_sys_progs_flag:
        cargs.append("-help_sys_progs")
    if apsearch is not None:
        cargs.extend([
            "-apsearch",
            apsearch
        ])
    if bindir is not None:
        cargs.extend([
            "-bindir",
            bindir
        ])
    if curl_flag:
        cargs.append("-curl")
    if do_dotfiles_flag:
        cargs.append("-do_dotfiles")
    if do_extras_flag:
        cargs.append("-do_extras")
    if echo_flag:
        cargs.append("-echo")
    if make_backup is not None:
        cargs.extend([
            "-make_backup",
            make_backup
        ])
    if no_cert_verify_flag:
        cargs.append("-no_cert_verify")
    if no_recur_flag:
        cargs.append("-no_recur")
    if proto is not None:
        cargs.extend([
            "-proto",
            proto
        ])
    if quick_flag:
        cargs.append("-quick")
    if show_obsoletes_flag:
        cargs.append("-show_obsoletes")
    if show_obsoletes_grep_flag:
        cargs.append("-show_obsoletes_grep")
    if show_system_progs_flag:
        cargs.append("-show_system_progs")
    if sys_ok_flag:
        cargs.append("-sys_ok")
    if test_flag:
        cargs.append("-test")
    if test_protos_flag:
        cargs.append("-test_protos")
    if revert_flag:
        cargs.append("-revert")
    if local_package is not None:
        cargs.extend([
            "-local_package",
            local_package
        ])
    if prog_list is not None:
        cargs.extend([
            "-prog_list",
            *prog_list
        ])
    if package is not None:
        cargs.extend([
            "-package",
            package
        ])
    ret = VUpdateAfniBinariesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VUpdateAfniBinariesOutputs",
    "V__UPDATE_AFNI_BINARIES_METADATA",
    "v__update_afni_binaries",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WBSPARSE_MERGE_DENSE_METADATA = Metadata(
    id="6eb20685f4c22c6b65becfd09a6b95edde9c4769.boutiques",
    name="wbsparse-merge-dense",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class WbsparseMergeDenseWbsparse:
    """
    specify an input wbsparse file.
    """
    wbsparse_in: str
    """a wbsparse file to merge"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-wbsparse")
        cargs.append(self.wbsparse_in)
        return cargs


class WbsparseMergeDenseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `wbsparse_merge_dense(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def wbsparse_merge_dense(
    direction: str,
    wbsparse_out: str,
    wbsparse: list[WbsparseMergeDenseWbsparse] | None = None,
    runner: Runner | None = None,
) -> WbsparseMergeDenseOutputs:
    """
    Merge wbsparse files along dense dimension.
    
    The input wbsparse files must have matching mappings along the direction not
    specified, and the mapping along the specified direction must be brain
    models.
    
    Author: Washington University School of Medicin
    
    Args:
        direction: which dimension to merge along, ROW or COLUMN.
        wbsparse_out: output - the output wbsparse file.
        wbsparse: specify an input wbsparse file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WbsparseMergeDenseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WBSPARSE_MERGE_DENSE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-wbsparse-merge-dense")
    cargs.append(direction)
    cargs.append(wbsparse_out)
    if wbsparse is not None:
        cargs.extend([a for c in [s.run(execution) for s in wbsparse] for a in c])
    ret = WbsparseMergeDenseOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WBSPARSE_MERGE_DENSE_METADATA",
    "WbsparseMergeDenseOutputs",
    "WbsparseMergeDenseWbsparse",
    "wbsparse_merge_dense",
]
